@@ -1,6 +1,6 @@
 #' Display a Help Page From a File's Documentation
 #'
-#' Display a \code{\link[utils]{help}}-like page from an existing R 
+#' Display a \code{\link[utils]{help}}-like page from an existing R
 #' documentation (*.Rd) file, a topic from a temporary package with the
 #' \code{option("document_package_directory")} set or a topic from an R code
 #' file containing \pkg{roxygen2} documentation.
@@ -24,22 +24,14 @@
 #' @export
 #' @examples
 #' \donttest{
-#' document(file_name = system.file("tests", "files", "minimal.R", 
+#' document(file_name = system.file("tests", "files", "minimal.R",
 #'          package = "document"), check_package = FALSE)
 #' man("foo")
 #' # this equivalent to
-#' path <- system.file("tests", "files", "minimal.R", package = "document") 
+#' path <- system.file("tests", "files", "minimal.R", package = "document")
 #' document::man(x = path, topic = "foo")
 #' }
 man <- function(x, topic = NA, force_Rd = FALSE) {
-    if (.Platform$GUI == "RStudio") {
-        if (.Platform$OS.type == "windows") {
-            r_interface <- normalizePath(Sys.which("Rgui"))
-        } else {
-            r_interface <- normalizePath(Sys.which("R"))
-        }
-        stop("Doesn't work with RStudio, use ", r_interface, " instead.")
-    }
     usage <- usage()
     if (file.exists(x)) {
         if (is_Rd_file(x) || ! identical(FALSE, force_Rd)) {
@@ -72,7 +64,7 @@ man <- function(x, topic = NA, force_Rd = FALSE) {
 }
 
 #' Return the Usage of a Function From Within the Function
-#' 
+#'
 #' Get a usage template for a function from within the function if you encounter
 #' misguided usage, you can display the template.
 #'
@@ -83,7 +75,7 @@ man <- function(x, topic = NA, force_Rd = FALSE) {
 #' want to obtain the usage for.
 #' Use the \code{<-} assignment operator with the default, see \bold{examples}
 #' below.
-#' @param usage Give this functions usage (as a usage example \ldots) and exit? 
+#' @param usage Give this functions usage (as a usage example \ldots) and exit?
 #' @return A character string giving the Usage as \code{\link{help}} would do.
 #' @export
 #' @examples
@@ -146,11 +138,15 @@ is_Rd_file <- function(x) {
 #' @return The return value of removing the temporary file.
 #' @param rd_file The path to the Rd file to be displayed.
 display_Rd <- function(rd_file) {
-    rd_out <- callr::rcmd_safe("Rdconv",
-                     c("--type=txt", rd_file))[["stdout"]]
-    rd_txt <- tempfile()
-    writeLines(rd_out, con = rd_txt)
-    file.show(rd_txt)
-    status <- file.remove(rd_txt)
+    if (.Platform$GUI == "RStudio") {
+        status <- rstudioapi::previewRd(rd_file)
+    } else {
+        rd_out <- callr::rcmd_safe("Rdconv",
+                                   c("--type=txt", rd_file))[["stdout"]]
+        rd_txt <- tempfile()
+        writeLines(rd_out, con = rd_txt)
+        file.show(rd_txt)
+        status <- file.remove(rd_txt)
+    }
     return(status)
 }
